summaryrefslogtreecommitdiffhomepage
path: root/src/raymath.h
diff options
context:
space:
mode:
authorraysan5 <[email protected]>2018-10-13 16:00:54 +0200
committerraysan5 <[email protected]>2018-10-13 16:00:54 +0200
commitcd6c36248531e9fe4b9e3220f34fd1d4a66c6533 (patch)
tree2b7196ba1c9fa835d4699b29bf8b2312cad0400b /src/raymath.h
parentc7b601b62465c7d38daed6fcc916bd94fdead1cf (diff)
downloadraylib-cd6c36248531e9fe4b9e3220f34fd1d4a66c6533.tar.gz
raylib-cd6c36248531e9fe4b9e3220f34fd1d4a66c6533.zip
Corrected func name typo
Diffstat (limited to 'src/raymath.h')
-rw-r--r--src/raymath.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/raymath.h b/src/raymath.h
index 33116532..1d5e26f9 100644
--- a/src/raymath.h
+++ b/src/raymath.h
@@ -300,7 +300,7 @@ RMDEF Vector3 Vector3Add(Vector3 v1, Vector3 v2)
return result;
}
// Substract two vectors
RMDEF Vector3 Vector3Subtract(Vector3 v1, Vector3 v2)
{
Vector3 result = { v1.x - v2.x, v1.y - v2.y, v1.z - v2.z };
@@ -720,8 +720,8 @@ RMDEF Matrix MatrixAdd(Matrix left, Matrix right)
return result;
}
-// Substract two matrices (left - right)
-RMDEF Matrix MatrixSubstract(Matrix left, Matrix right)
+// Subtract two matrices (left - right)
+RMDEF Matrix MatrixSubtract(Matrix left, Matrix right)
{
Matrix result = MatrixIdentity();
@@ -300,7 +300,7 @@ RMDEF Vector3 Vector3Add(Vector3 v1, Vector3 v2)
return result;
}
-// Substract two vectors
+// Subtract two vectors
RMDEF Vector3 Vector3Subtract(Vector3 v1, Vector3 v2)
{